# Generated by Django 2.2.4 on 2019-09-13 18:24

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('devices', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Passepartout',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('deleted', models.BooleanField(default=False)),
                ('token', models.CharField(db_index=True, max_length=36, unique=True)),
                ('jwt', models.TextField()),
                ('bumps', models.PositiveIntegerField(default=0)),
                ('device', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='devices.Device', verbose_name='device')),
            ],
            options={
                'unique_together': {('token', 'deleted')},
            },
        ),
    ]
