# -*- coding: utf-8 -*-
"""
    Dummy conftest.py for django_sso_app.

    If you don't know what this is for, just leave it empty.
    Read more about conftest.py under:
    https://pytest.org/latest/plugins.html
"""

# import pytest
# import os
# import sys

# os.environ['DJANGO_SETTINGS_MODULE'] = 'backend.settings.test'
# sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
