# Generated by Django 2.2.4 on 2019-09-13 18:24

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Device',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('fingerprint', models.CharField(max_length=32)),
                ('user_agent', models.CharField(blank=True, max_length=32, null=True)),
                ('apigw_jwt_id', models.CharField(blank=True, max_length=36, null=True)),
                ('apigw_jwt_key', models.CharField(blank=True, max_length=32, null=True)),
                ('apigw_jwt_secret', models.CharField(blank=True, max_length=32, null=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='devices', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
