# Generated by Django 2.2.4 on 2019-09-13 18:24

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='user',
            options={},
        ),
        migrations.AddField(
            model_name='user',
            name='apigw_consumer_id',
            field=models.CharField(blank=True, max_length=36, null=True, verbose_name='apigw consumer id'),
        ),
        migrations.AddField(
            model_name='user',
            name='sso_id',
            field=models.UUIDField(db_index=True, default=uuid.uuid4, editable=False, unique=True, verbose_name='sso id'),
        ),
        migrations.AddField(
            model_name='user',
            name='sso_rev',
            field=models.PositiveIntegerField(default=1, verbose_name='sso revision'),
        ),
        migrations.AddField(
            model_name='user',
            name='unsubscribed_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='unsubscription date'),
        ),
    ]
