# Generated by Django 2.2.4 on 2019-09-13 18:24

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=True, verbose_name='is active')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='created at')),
                ('updated_at', models.DateTimeField(blank=True, editable=False, null=True, verbose_name='updated at')),
                ('sso_id', models.CharField(blank=True, db_index=True, max_length=36, null=True, unique=True)),
                ('sso_rev', models.PositiveIntegerField(default=0)),
                ('first_name', models.CharField(blank=True, max_length=30, null=True, verbose_name='first name')),
                ('last_name', models.CharField(blank=True, max_length=30, null=True, verbose_name='last name')),
                ('role', models.SmallIntegerField(blank=True, null=True)),
                ('description', models.TextField(blank=True, null=True, verbose_name='description')),
                ('picture', models.TextField(blank=True, null=True, verbose_name='picture')),
                ('birthdate', models.DateField(blank=True, null=True, verbose_name='birthdate')),
                ('latitude', models.FloatField(blank=True, null=True, verbose_name='latitude')),
                ('longitude', models.FloatField(blank=True, null=True, verbose_name='longitude')),
                ('country', models.CharField(blank=True, max_length=46, null=True, verbose_name='country')),
                ('address', models.TextField(blank=True, null=True, verbose_name='address')),
                ('unsubscribed_at', models.DateTimeField(blank=True, null=True)),
                ('language', models.CharField(blank=True, max_length=3, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='sso_app_profile', to=settings.AUTH_USER_MODEL, verbose_name='user')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
