{% extends "base.html" %}
{% block title %}{% block head_title %}{% endblock head_title %}{% endblock title %}

{% block content %}
<div class="row">
  <div class="col-md-6 offset-md-3">
    {% block inner %}{% endblock %}
  </div>
</div>
{% endblock %}
