{% load static i18n %}<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>{% block title %}Django SSO App{% endblock title %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">
    <meta name="author" content="">

    <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
    <!--[if lt IE 9]>
      <script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.min.js"></script>
    <![endif]-->

    <link rel="icon" href="{% static 'images/favicons/favicon.ico' %}">

    {% block css %}
    
    <!-- Latest compiled and minified Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-ggOyR0iXCbMQv3Xipma34MD+dH/1fQ784/j6cY/iJTQUOhcWr7x9JvoRxT2MZw1T" crossorigin="anonymous">
    

    <!-- Your stuff: Third-party CSS libraries go here -->
    
    <!-- This file stores project-specific CSS -->
    
    <link href="{% static 'css/project.css' %}" rel="stylesheet">
    
    
    {% endblock %}

  </head>

  <body>

    <div class="mb-1">
      <nav class="navbar navbar-expand-md navbar-light bg-light">
        <button class="navbar-toggler navbar-toggler-right" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
          <span class="navbar-toggler-icon"></span>
        </button>
        <a class="navbar-brand" href="{% url 'home' %}">Django SSO App</a>

        <div class="collapse navbar-collapse" id="navbarSupportedContent">
          <ul class="navbar-nav mr-auto">
            <li class="nav-item active">
              <a class="nav-link" href="{% url 'home' %}">Home <span class="sr-only">(current)</span></a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'about' %}">About</a>
            </li>
            {% if DJANGO_ALLAUTH_ENABLED %}
              {% if request.user.is_authenticated %}
                <li class="nav-item">
                  {# URL provided by django-allauth/account/urls.py #}
                  <a class="nav-link" href="/profile/">{% trans "My Profile" %}</a>
                </li>
                <li class="nav-item">
                  {# URL provided by django-allauth/account/urls.py #}
                  <a class="nav-link" href="{% url 'account_logout' %}">{% trans "Sign Out" %}</a>
                </li>
              {% else %}
                <li class="nav-item">
                  {# URL provided by django-allauth/account/urls.py #}
                  <a id="sign-up-link" class="nav-link" href="{% url 'account_signup' %}">{% trans "Sign Up" %}</a>
                </li>
                <li class="nav-item">
                  {# URL provided by django-allauth/account/urls.py #}
                  <a id="log-in-link" class="nav-link" href="{% url 'account_login' %}">{% trans "Sign In" %}</a>
                </li>
              {% endif %}
            {% endif %}
          </ul>
        </div>
      </nav>

    </div>

    <div class="container">

      {% if messages %}
          {% for message in messages %}
              <div class="alert {% if message.tags %}alert-{{ message.tags }}{% endif %}">{{ message }}<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button></div>
          {% endfor %}
      {% endif %}

      {% block content %}
        <p>Use this document as a way to quick start any new project.</p>
      {% endblock content %}

    </div> <!-- /container -->

    {% block modal %}{% endblock modal %}

    <!-- Le javascript
    ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    {% block javascript %}
      
      <!-- Bootstrap JS and its dependencies-->
      <script src="https://code.jquery.com/jquery-3.3.1.slim.min.js" integrity="sha384-q8i/X+965DzO0rT7abK41JStQIAqVgRVzpbzo5smXKp4YfRvH+8abtTE1Pi6jizo" crossorigin="anonymous"></script>
      <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.14.3/umd/popper.min.js" integrity="sha384-ZMP7rVo3mIykV+2+9J3UJ46jBk0WLaUAdn689aCwoqbBJiSnjAK/l8WvCWPIPm49" crossorigin="anonymous"></script>
      <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.3.1/js/bootstrap.min.js" integrity="sha384-JjSmVgyd0p3pXB1rRibZUAYoIIy6OrQ6VrjIEaFf/nJGzIxFDsf4x0xIM+B07jRM" crossorigin="anonymous"></script>

      <!-- Your stuff: Third-party javascript libraries go here -->
      

      <!-- place project specific Javascript in this file -->
      
      <script src="{% static 'js/project.js' %}"></script>
      

    {% endblock javascript %}
  </body>
</html>
 
