<style>
    #allauth {
        text-align: center;
        width: 360px;
        max-width: 100%;
        overflow: hidden;
        margin: auto;
    }
    #allauth .errorList {
        color: #f44336;
    }
    #allauth .head {
        padding: 32px 0 0;
    }
    #allauth form {
        margin: 32px 0 64px;
        text-align: left;
        overflow: hidden;
    }
    #allauth form > p {
        line-height: 36px;
        overflow: hidden;
    }
    #allauth form > p > input,
    #allauth form > button,
    #allauth form > input {
        height: 32px;
        line-height: 28px;
        font-size: 16px;
        border-radius: 3px;
        border: none;
        background-color: #fff;
        color: #111;
        float: right;
    }
    #allauth form > p > input {
        padding: 0 8px;
    }
    #allauth form > p > textarea {
        width: 100%;
        border: none;
        border-radius: 3px;
    }
    #allauth form fieldset {
        text-align: left;
        border: 1px solid #fff;
    }
    #allauth form fieldset .buttonHolder {
        margin: 16px 0;
    }
    #allauth form > button,
    #allauth form input[type=submit] {
        margin: 16px 0 0;
        float: right;
        height: 42px;
        padding: 0 12px;
        cursor: pointer;
    }
    #allauth .user-profile a {
        margin: 8px;
    }
</style>
